- remove unneeded patches, all the random devices have been providing the same

output for a while now
This commit is contained in:
jasper 2011-07-07 16:59:36 +00:00
parent 9b32b32eaa
commit ff7d1db752
7 changed files with 6 additions and 95 deletions

View File

@ -1,9 +1,10 @@
# $OpenBSD: Makefile,v 1.42 2011/05/01 11:34:17 ajacoutot Exp $
# $OpenBSD: Makefile,v 1.43 2011/07/07 16:59:36 jasper Exp $
COMMENT= high-performance CORBA Object Request Broker
GNOME_PROJECT= ORBit2
GNOME_VERSION= 2.14.19
REVISION= 0
SHARED_LIBS += ORBit-2 3.0 # .1.0
SHARED_LIBS += ORBitCosNaming-2 3.0 # .1.0

View File

@ -1,12 +0,0 @@
$OpenBSD: patch-src_orb_util_genrand_c,v 1.1 2009/03/23 07:29:18 jakemsr Exp $
--- src/orb/util/genrand.c.orig Sun Mar 22 20:31:38 2009
+++ src/orb/util/genrand.c Sun Mar 22 20:31:48 2009
@@ -73,7 +73,7 @@ ORBit_genuid_init (ORBitGenUidType type)
switch (genuid_type) {
case ORBIT_GENUID_STRONG:
#ifndef G_OS_WIN32
- random_fd = open ("/dev/urandom", O_RDONLY);
+ random_fd = open ("/dev/arandom", O_RDONLY);
if (random_fd < 0)
random_fd = open ("/dev/random", O_RDONLY);

View File

@ -1,9 +1,9 @@
# $OpenBSD: Makefile,v 1.7 2010/11/15 19:45:56 espie Exp $
# $OpenBSD: Makefile,v 1.8 2011/07/07 16:59:36 jasper Exp $
COMMENT= implementation of the Real-time Transport Protocol
DISTNAME= ccrtp-1.7.1
REVISION = 0
REVISION = 1
CATEGORIES= devel
MASTER_SITES= ${MASTER_SITE_GNU:=ccrtp/}

View File

@ -1,27 +0,0 @@
$OpenBSD: patch-doc_ccrtp_texi,v 1.1 2009/03/25 08:58:04 jakemsr Exp $
--- doc/ccrtp.texi.orig Sun Mar 22 23:59:42 2009
+++ doc/ccrtp.texi Mon Mar 23 00:00:17 2009
@@ -258,9 +258,9 @@ Starting with 1.0 releases, ccRTP fully supports @acro
@item Implements timer reconsideration and reverse reconsideration.
@cindex Random numbers
-@cindex /dev/urandom
+@cindex /dev/arandom
@cindex MD5
-@item Provides good random numbers, based on @file{/dev/urandom} or, alternatively, on MD5.
+@item Provides good random numbers, based on @file{/dev/arandom} or, alternatively, on MD5.
@end itemize
@@ -1326,9 +1326,9 @@ Code in A.5 is implemented in the method
@cindex A.6
@cindex Random numbers
-@cindex /dev/urandom
+@cindex /dev/arandom
@cindex MD5
-On POSIX systems, ccRTP uses @file{/dev/urandom} when available. If
+On POSIX systems, ccRTP uses @file{/dev/arandom} when available. If
there is no such device, it defaults to the MD5 based algorithm given
in appendix A.6.

View File

@ -1,12 +0,0 @@
$OpenBSD: patch-src_queue_cpp,v 1.1 2009/03/25 08:58:04 jakemsr Exp $
--- src/queue.cpp.orig Sun Mar 22 23:58:11 2009
+++ src/queue.cpp Sun Mar 22 23:59:06 2009
@@ -499,7 +499,7 @@ uint32 random32()
uint32 number;
#ifndef WIN32
bool success = true;
- int fd = open("/dev/urandom",O_RDONLY);
+ int fd = open("/dev/arandom",O_RDONLY);
if (fd == -1) {
success = false;
} else {

View File

@ -1,9 +1,9 @@
# $OpenBSD: Makefile,v 1.30 2010/11/15 19:46:09 espie Exp $
# $OpenBSD: Makefile,v 1.31 2011/07/07 16:59:36 jasper Exp $
COMMENT= toolkit for the development of SILC applications
DISTNAME= silc-toolkit-1.1.10
REVISION = 2
REVISION = 3
CATEGORIES= devel
MASTER_SITES= http://www.silcnet.org/download/toolkit/sources/

View File

@ -1,39 +0,0 @@
$OpenBSD: patch-lib_silccrypt_silcrng_c,v 1.1 2009/03/29 09:13:01 sthen Exp $
--- lib/silccrypt/silcrng.c.orig Mon Mar 23 10:15:01 2009
+++ lib/silccrypt/silcrng.c Mon Mar 23 10:15:19 2009
@@ -218,7 +218,7 @@ void silc_rng_init(SilcRng rng)
silc_rng_get_hard_noise(rng);
silc_rng_get_soft_noise(rng);
silc_free(rng->devrandom);
- rng->devrandom = strdup("/dev/urandom");
+ rng->devrandom = strdup("/dev/arandom");
}
/* This function gets 'soft' noise from environment. */
@@ -552,7 +552,7 @@ SilcUInt8 silc_rng_get_byte(SilcRng rng)
return byte;
}
/* Return random byte as fast as possible. Reads from /dev/urandom if
available. If not then return from normal RNG (not so fast). */
SilcUInt8 silc_rng_get_byte_fast(SilcRng rng)
@@ -561,7 +561,7 @@ SilcUInt8 silc_rng_get_byte_fast(SilcRng rng)
unsigned char buf[1];
if (rng->fd_devurandom == -1) {
- rng->fd_devurandom = open("/dev/urandom", O_RDONLY);
+ rng->fd_devurandom = open("/dev/arandom", O_RDONLY);
if (rng->fd_devurandom < 0)
return silc_rng_get_byte(rng);
fcntl(rng->fd_devurandom, F_SETFL, O_NONBLOCK);
@@ -678,7 +678,7 @@ SilcUInt8 silc_rng_global_get_byte(void)
return global_rng ? silc_rng_get_byte(global_rng) : 0;
}
/* Return random byte as fast as possible. Reads from /dev/urandom if
available. If not then return from normal RNG (not so fast). */
SilcUInt8 silc_rng_global_get_byte_fast(void)
@@ -552,7 +552,7 @@ SilcUInt8 silc_rng_get_byte(SilcRng rng)
return byte;
}
-/* Return random byte as fast as possible. Reads from /dev/urandom if
+/* Return random byte as fast as possible. Reads from /dev/arandom if
available. If not then return from normal RNG (not so fast). */
SilcUInt8 silc_rng_get_byte_fast(SilcRng rng)
@@ -678,7 +678,7 @@ SilcUInt8 silc_rng_global_get_byte(void)
return global_rng ? silc_rng_get_byte(global_rng) : 0;
}
-/* Return random byte as fast as possible. Reads from /dev/urandom if
+/* Return random byte as fast as possible. Reads from /dev/arandom if
available. If not then return from normal RNG (not so fast). */
SilcUInt8 silc_rng_global_get_byte_fast(void)